<?php
/**
 * Add image sizes to theme
 *
 * @since 0.1.17
 *
 */

class UBC_CLF_Lite_Theme_Support {

	/**
	 * Set up filter hooks for main html tag classes
	 *
	 * @since 1.0.0
	 *
	 */
	public function init() {
		// add_action( 'after_setup_theme', array( $this, 'wp_clf_lite_remove_header_theme_support_then_add_back' ) );
		add_filter( 'wp_clf_lite_custom_header_setup', array( $this, 'wp_clf_lite_custom_header_setup_ext' ) );
		add_action( 'wp_clf_lite_course_section_open_close_accordion', array( $this, 'get_course_section_accordion_open_close_button' ) );
		add_action( 'course_sections_navigation', array( $this, 'get_course_sections_navigation' ) );
		add_action( 'init', array( $this, 'add_main_header_navigation' ) );
		add_filter( 'excerpt_more', array( $this, 'ubc_excerpt_more' ), -1 );

	}


	public function wp_clf_lite_custom_header_setup_ext( ) {

		$args = array(

			'default-image'          => '',
			'default-text-color'     => '000000',
			'width'                  => 1440,
			'height'                 => 400,
			'flex-height'            => true,
			'wp-head-callback'       => 'wp_clf_lite_header_style',
			'admin-head-callback'    => 'wp_clf_lite_admin_header_style',
			'admin-preview-callback' => 'wp_clf_lite_admin_header_image',

		);

		return $args;

	}

	/**
	 * Add new menu location in the header
	 * 
	 */

	public function add_main_header_navigation() {

		register_nav_menu( 'main-header-navigation', __( 'Top header menu', 'wp-clf-lite' ) );
	}

	/**
	 * get_course_title() function gets either the site title or the theme mod title raw
	 * 
	 * @since 0.1.39
	 *
	 * @param string $site_title
	 * @param string $course_title string
	 * @param string $get_course_title
	 * 
	 * @return string $get_course_title
	 */
	public static function get_course_title() {

		$site_title 	  = get_bloginfo( 'name' );
		$course_title	  = get_theme_mod( 'course_title' );
		$get_course_title = ! empty( $course_title ) ? $course_title : $site_title;

			return esc_html( $get_course_title );

	}

	/**
	 * course_title() function gets either the site title or the theme mod title with a before or after for tag elements
	 * 
	 * @since 0.1.39
	 *
	 * @param string $site_title = UBC_CLF_Lite_Theme_Support::get_course_title()
	 * @param string $before html tag opening
	 * @param string $after  html tag closing
	 * 
	 * @return string $course_title
	 */
	public static function course_title( $before = '', $after = '' ) {

		$site_title = UBC_CLF_Lite_Theme_Support::get_course_title();

		if ( empty( $site_title ) )
			return;

		$course_title = $before . $site_title . $after;

			echo wp_kses_post( $course_title );

	}

	/**
	 * get_course_description() function gets the course description
	 * 
	 * @since 0.1.39
	 *
	 * @param string $course_description 
	 * 
	 * @return string $course_description 
	 */
	public static function get_course_description() {

		$course_description = ( ! empty( get_theme_mod( 'course_decription' ) ) ? get_theme_mod( 'course_decription' ) : '' );

			return esc_html( get_theme_mod( 'course_decription' ) );

	}

	/**
	 * course_description() function gets the course description with before and after tags
	 * 
	 * @since 0.1.39
	 *
	 * @param string $get_course_description = UBC_CLF_Lite_Theme_Support::get_course_description();
	 * @param string $before - html tag before
	 * @param string $after - html tag after
	 * 
	 * @return string $course_description 
	 */
	public static function course_description( $before = '', $after = '' ) {

		$get_course_description = UBC_CLF_Lite_Theme_Support::get_course_description();

		if ( empty( $get_course_description ) ) :

			return;

		else:

			$course_description = $before . $get_course_description . $after;
			echo wp_kses_post( $course_description );

		endif;

	}

	/**
	 * get_course_section_accordion_open_close_button() display accoridion button if website has sections
	 * 
	 * @since 0.1.39
	 *
	 * @param boolean $has_section - function from UBC PRESS if has posts in section post type
	 * 
	 * @return string template
	 */
	public function get_course_section_accordion_open_close_button() {

		$has_section = \UBC\Press\Utils::course_has_section();

		if ( empty( $has_section )  ) :

			return;

		else :

			require_once( trailingslashit( get_stylesheet_directory() ) . '/template-parts/expand-collapse-accordion.php' );

		endif;

	}

	/**
	 * get_faculty_unit_title() return a raw text version of the selected faculty
	 * 
	 * @since 0.1.39
	 *
	 * @param array $stakeholder
	 * @param array $faculty_list
	 * 
	 * @return string $faculty_list[ $stakeholder ];
	 */
	public static function get_faculty_unit_title() {

		$option_default = get_theme_mod( 'faculty_school', '' );

		if ( empty( $option_default ) ) {

			return;
		}

		$faculty_list = \UBC\Press\Utils::get_faculty_list();
		$stakeholder_list = $faculty_list[ $option_default ];

		return $stakeholder_list;

	}

	/**
	 * faculty_unit_title() return faculty title with ability to add html tags
	 * 
	 * @since 0.1.39
	 *
	 * @param string $get_faculty - UBC_CLF_Lite_Theme_Support::get_faculty_unit_title()
	 * @param string $faculty
	 * 
	 * @return string $faculty - faculty title
	 */
	public static function faculty_unit_title( $before = '', $after = ''  ) {

		$get_faculty = UBC_CLF_Lite_Theme_Support::get_faculty_unit_title();

		if ( empty( $get_faculty ) ) {

			return;
		}

			$faculty = $before . $get_faculty . $after;
			echo wp_kses_post( $faculty );

	}

	/**
	 * get_course_sections_navigation() do action to display course navigation
	 * 
	 * @since 0.1.39
	 *
	 * @param array $args - list of arguments
	 * @param array $get_sections_array = gets all sections based of $args
	 * @param array $sections = gets all sections ids
	 * 
	 * @return string $faculty - faculty title
	 */
	public static function get_course_sections_navigation() {

		// check if website has sections
		$has_section = \UBC\Press\Utils::course_has_section();

		if ( empty( $has_section )  )
			return;

		// get the post id and post parent id.
		global $post;
		$the_post_id = $post->ID;
		$the_post_parent = wp_get_post_parent_id( $the_post_id );

		// arguments for get_posts
		$args = array(
			'post_type' 	=> 'section',
			'sort_column'	=> 'menu_order',
			'sort_order'    => 'asc',
			'exclude'   	=> array( $the_post_parent ),
			'parent'		=> $the_post_parent,
		);

		// get sections
		$get_sections_array = get_pages( $args );

		// set up empty array for section ids
		$sections = array();
		foreach( $get_sections_array as $section ) :
			$sections[] += $section->ID;
		endforeach;

		// get the post ids for the prev and next sections
		$get_current_post_id     = array_search( $the_post_id, $sections );
		$get_previous_section_id = ! empty( $sections[ $get_current_post_id - 1 ] ) ? $sections[ $get_current_post_id - 1 ] : '';
		$get_next_section_id 	 = ! empty( $sections[ $get_current_post_id + 1 ] ) ? $sections[ $get_current_post_id + 1 ] : '';

		if ( empty( $get_previous_section_id ) && empty( $get_next_section_id  ) ) {

			return;
		}

		// get prev and next url
		$previous_url = ! empty( $get_previous_section_id ) ? get_permalink( intval( $get_previous_section_id ) ) : '';
		$next_url 	  = ! empty( $get_next_section_id ) ? get_permalink( intval( $get_next_section_id ) ) : '';

		// get prev and next section title
		$get_prev_title = get_the_title( $get_previous_section_id );
		$get_next_title = get_the_title( $get_next_section_id );

		// store it all in an array and pass it to template
		$get_prev_next = array(
			'prev' => array(
				'id'	=> $get_previous_section_id,
				'url'	=> $previous_url,
				'title'	=> $get_prev_title,
			),
			'next' => array(
				'id'	=> $get_next_section_id,
				'url'	=> $next_url,
				'title' => $get_next_title,
			), 
		);

		// get the template path and file ready
		$startPath = trailingslashit( dirname( __FILE__ ) ) . '../template-parts';
		$dashboard_menu_templ = 'single-section-footer-navigation.php';

		// call the template with our data
		\UBC\Helpers::locate_template_part_in_plugin( $startPath, $dashboard_menu_templ, true, false, $get_prev_next );

	}

	/**
	 * get_site_type() return a raw text from customizer options
	 * 
	 * @since 0.1.50
	 *
	 * @param array $stakeholder
	 * @param array $faculty_list
	 * 
	 * @return string $faculty_list[ $stakeholder ];
	 */
	public static function get_site_type() {

		if ( empty( get_theme_mod( 'site_type_convention' ) ) )
			return;

		return get_theme_mod( 'site_type_convention' );

	}

	/**
	 * site_type() return faculty title with ability to add html tags
	 * 
	 * @since 0.1.40
	 *
	 * @param string $before - html before
	 * @param string $after - html after
	 * 
	 * @return string echo $faculty - faculty title
	 */
	public static function site_type( $before = '', $after = ''  ) {

		$get_site_type = UBC_CLF_Lite_Theme_Support::get_site_type();

		if ( empty( $get_site_type ) )
			return;

			$site_type = $before . $get_site_type . $after;
			echo wp_kses_post( $site_type );

	}

	/**
	 * top_banner_image() returns the top banner
	 * 
	 * @since 0.1.40
	 * 
	 * @return mixed array - get_query_var( 'template_data' ) with template
	 */
	public static function top_banner_image() {

		$dashboard_page 			= get_query_var( 'studentdashboard' );
		$section_component_page 	= get_query_var( 'get_coursecontent' );

		// lets just return empty if on dashboard, component section page, or if post thumb and header image empty
		if ( ! empty( $dashboard_page ) || ! empty( $section_component_page ) || is_search() || ( empty( has_header_image() ) && empty( has_post_thumbnail() ) ) )
			return;

		// Arguments for image functions
		$args        = array( 'id' => 'img-responsive', 'data-resize' => '.site-banner' );
		// If post has thumbnail us wp_get_attachment_image with the attachment id so we can pass some arguments
		$banner_img  = has_post_thumbnail() && ! is_home() && ! is_front_page() ? wp_get_attachment_image( get_post_thumbnail_id() , 'home-page-banner', '', $args ) : get_header_image_tag( $args );

		if ( empty( $banner_img ) )
			return;

		// get the template path and file ready
		$startPath = trailingslashit( dirname( __FILE__ ) ) . '../template-parts';
		$dashboard_menu_templ = 'content-banner-img.php';

		// call the template with our data
		\UBC\Helpers::locate_template_part_in_plugin( $startPath, $dashboard_menu_templ, true, false, array( $banner_img ) );

	}

	/**
	 * If section only has forum/forum topic
	 * 
	 * @param string $post_id the post id
	 * @return boolean null
	 */
	public static function ubc_single_component_type( $post_id ) {

		if ( empty( $post_id ) ) {
			return;
		}

		$section_components = \UBC\Press\Utils::get_all_section_component_meta_value( $post_id );

		$component_count = is_array( $section_components ) ? count( $section_components ) : null;

		if ( empty( $component_count ) || 1 === $component_count ) {
			return;
		}

		if ( ! in_array( 'forum', $section_components['type'] ) && ! in_array( 'topic', $section_components['type'] ) && ! in_array( 'h5p', $section_components['type'] ) ) {
			return;
		}

		// file_put_contents( trailingslashit( WP_CONTENT_DIR ) . 'debug.log', print_r( array( $section_components ), true ), FILE_APPEND );

		if ( empty( $section_components['type'] ) ) {

			return;
		}

		// file_put_contents( trailingslashit( WP_CONTENT_DIR ) . 'debug.log', print_r( array( $section_components['type'] ), true ), FILE_APPEND );

		return $section_components['type'];

	}

	/**
	 * Single component icon
	 * 
	 */

	 public static function ubc_single_component_type_icon( $post_id = '' ) {


		if ( empty( $post_id ) ) {

			return;

		}

		$type = UBC_CLF_Lite_Theme_Support::ubc_single_component_type( $post_id );


		if ( empty( $type ) ) {

			return;
		}

		// file_put_contents( trailingslashit( WP_CONTENT_DIR ) . 'debug.log', print_r( array( $type ), true ), FILE_APPEND );

		$icon_name = '';

		switch ( $type[0] ) {

			case 'forum':
			case 'topic':
				$icon_name = 'discussions';
				break;
			case 'h5p':
				$icon_name = 'awards';
				break;
		}

		// file_put_contents( trailingslashit( WP_CONTENT_DIR ) . 'debug.log', print_r( array( $icon_name ), true ), FILE_APPEND );

		return $icon_name;
	 }

	/**
	 * Gets all the settings for the sections list item
	 *
	 * @since 0.1.42
	 *
	 * @return array $item_settings - get_query_var( 'template_data' ) with template
	 */
	public static function ubc_courses_sections_list_item_settings( $post_id = '', $current_section_class = '' ) {

		if ( empty( $post_id ) ) {
			return;
		}

		// Filter to short-circuit display of this item.
		$display = apply_filters( 'wp_clf_lite_display_course_section_list_item', null, $post_id );
		if ( null !== $display ) {
			return;
		}

		// Find out the number of completed components for this section. @TODO: AJAX call?
		$completed_comps_data = \UBC\Press\Utils::completed_components_for_section( $post_id );
		// $completed_comps_data will contain ['completed_components'] and 'total_components'
		$num_completed_components	= is_array( $completed_comps_data['completed_components'] ) ? count( $completed_comps_data['completed_components'] ) : 0;
		// $completed_comps_data will contain ['completed_components'] and 'total_components'
		$num_total_components = $completed_comps_data['total_components'];
		// Find the percentage for completed components complete / total * 100. Assume 100 when no completable.
		$num_percentage				= ( 0 === $num_total_components || null === $num_total_components ) ? 100 : ( ($num_completed_components / $num_total_components) * 100 );
		// Set class for 100% complete.
		$section_completed		= ( 100 === $num_percentage ) ? 'completed' : '';
		// Set class for when complete components is zero or another class when progress has started.
		$section_status 	= ( 0 === $num_completed_components ) ? 'no-complete' : 'start-progress';
		$completed_text = sprintf( __( '%1$sCompleted: %2$s%3$s/%4$s', 'ubc-wp-clf-lite' ),
			'<span class="completed-text">',
			'</span>',
			'<span class="completed-components">' . absint( $num_completed_components ) . '</span>',
			'<span class="total-components">' . absint( $num_total_components ) . '</span>'
		);
		$no_completable_components_text = __( 'None to complete', 'ubc-wp-clf-lite' );
		$comp_text_to_output = ( $num_total_components > 0 ) ? $completed_text : $no_completable_components_text;

		// Class for section listing: .current_page_item or .page_item.
		$page_class = empty( $current_section_class ) ? 'current-page-item' : $current_section_class;
		global $wp_query;
		$the_post_id = $wp_query->post->ID;

		// set up settings array
		$item_settings = array();

		$item_settings['post_id'] = $post_id;
		// Checking to see if mark as completed is set to be used.
		$item_settings['show_mark_complete_btn'] = \UBC\Press\Utils::do_components_show_mark_as_complete();
		$item_settings['num_completed_components'] = $num_completed_components;
		$item_settings['num_total_components'] = $completed_comps_data['total_components'];
		$item_settings['num_percentage'] = $num_percentage;
		$item_settings['section_completed'] = $section_completed;
		$item_settings['section_status'] = $section_status;
		$item_settings['completed_text'] = $completed_text;
		$item_settings['no_completable_components_text'] = $no_completable_components_text;
		$item_settings['comp_text_to_output'] = $comp_text_to_output;
		$item_settings['current_section_class'] = ( $the_post_id === $post_id ) ? $page_class : '';
		$item_settings['single_component_icon'] = UBC_CLF_Lite_Theme_Support::ubc_single_component_type_icon( $post_id );

		return $item_settings;

	}

	/**
	 * Template part for course section list item
	 *
	 * @since 0.1.42
	 *
	 * @return string template-parts/courses-section-list.php
	 */
	public static function ubc_courses_sections_list_item( $post_id = '' ) {

		if ( empty( $post_id ) ) {
			return;
		}

		$item_settings = UBC_CLF_Lite_Theme_Support::ubc_courses_sections_list_item_settings( $post_id );

		if ( ! array( $item_settings ) ) {
			return;
		}

		return include( locate_template( 'template-parts/courses-section-list.php', false, false ) );

	}

	// public static function section_only_contains_forum( $post_id = '' ) {

	// 	if ( empty( $post_id ) ) {

	// 		return;

	// 	}

	// 	$sections = \UBC\Press\Utils::get_component_types_from_section_id( $post_id );

	// 	if ( empty( $sections ) ) {

	// 		return;
	// 	}

	// 	$section_types = '';




	// }

	/**
	 * A link for the course listing page.
	 * 
	 * @param string $classes = link classes
	 * @param string $title = link title
	 * @param string $icon = icon name
	 */

	public static function section_listing_link( $classes = 'button success course-button', $title = 'Course content', $icon = 'list' ) {

		$is_section 	    = \UBC\Press\Utils::course_has_section();
		$section_archive    = is_post_type_archive( 'section' );
		$section 		    = get_post_type();
		$sections_on_front 	= get_option( 'show_on_front' );

		if ( empty( $is_section ) || ! empty( $section_archive ) || 'section' === $section || 'sections' === $sections_on_front ) {

			return;
		}

		$get_site_type			= \UBC_CLF_Lite_Theme_Support::get_site_type();
		$section_type			= \UBC_WP_CLF_Lite::get_course_content_name_convention_plural();
		$section_archive_link 	= get_post_type_archive_link( 'section' );

		return '<a class="'. esc_attr( $classes ) .'" href="'. esc_url( $section_archive_link ) .'" title="'. esc_attr( $title ) .'"><svg class="ui-icon pencil"><use xlink:href="#'. esc_html( $icon ) .'"></use></svg> '. esc_html( $get_site_type ) .' '. esc_html( $section_type ) .'</a>';

	}

	/**
	 * Get the users login name or prompt loging
	 */

	public static function ubc_get_username() {

		$user 	= wp_get_current_user();

		if ( empty( $user->ID ) ) {

			return;

		}

		return $user->display_name;

	}

	/**
	 * Main/User menu header btn
	 */
	public static function main_menu_open_btn() {

		if ( ! is_user_logged_in() && ! has_nav_menu( 'primary' ) ) {

			return;

		}

		return include( locate_template( 'template-parts/content-main-menu-open-btn.php', false, false ) );

	}

	/**
	 * If has user Dashboard menu
	 * 
	 */
	public static function user_dashboard_menu() {

		$has_section = \UBC\Press\Utils::course_has_section();

		if ( empty( $has_section ) ) {

			return;

		}

		return include( locate_template( 'template-parts/content-dashboard-menu.php', false, false ) );
	}

	/**
	 * Filter the "read more" excerpt string link to the post.
	 *
	 * @param string $more "Read more" excerpt string.
	 * @return string (Maybe) modified "read more" excerpt string.
	 */
	public function ubc_excerpt_more( $excerpt_text ) {

		if ( is_search() ) :

			$permalink = add_query_arg( $_GET, get_permalink() );

		else :

			$permalink = get_permalink();

		endif;

			$excerpt_text = sprintf( '... <a class="read-more" href="%1$s">%2$s</a>',
				esc_url( $permalink ),
				__( 'Read More', 'wp-clf-lite' )
			);

		return $excerpt_text;
	}

}

// Initialize our child theme changes.
add_action( 'after_setup_theme', 'after_setup_theme_ubc_clf_lite_theme_support_class_hooks_init', 15 );


/**
 * Initialize the UBC_CLF_Lite_Customizer class on after_setup_theme so we're
 * up and running AFTER the parent theme (priority 15)
 *
 * @since 1.0.0
 *
 * @param null
 * @return null
 */

function after_setup_theme_ubc_clf_lite_theme_support_class_hooks_init() {

	$UBC_CLF_Add_Theme_Options = new UBC_CLF_Lite_Theme_Support();
	$UBC_CLF_Add_Theme_Options->init();

}/* after_setup_theme_ubc_clf_lite_theme_support_class_hooks_init() */
